Attribute VB_Name = "I332_IFC"
Option Explicit

'{------------------------------------------------------------------------------}
'{ Interface-Unit fr die I332.DLL:                                             }
'{ Schnittstellen-DLL fr die Maschinensteuerung I332 / Fa. Pfortner GmbH       }
'{                                                                              }
'{ Alle Schnittstelle-Routinen sind Funktionen, die ein (positives)             }
'{ Funktionsergebnis oder eine (negative) Fehlernummer zurckliefern.           }
'{ Die DLL ist in der Lage, mehrere I332 in einem System zu verwalten.          }
'{ Die Kommunikation mit einer spezifischen I332 erfolgt ber ein Handle, das   }
'{ durch den Aufruf der Initialisierungsfunktion bereitgestellt wird.           }
'{                                                                              }
'{ Alle Routinen benutzen das Aufruf-Modell stdcall (entspr. der                }
'{ C/C++ - Direktive "WinAPI").                                                 }
'{                                                                              }
'{ Die I332.DLL ist threadfest; alle Funktionen fangen mgliche Fehler          }
'{ mit dem try..except-Mechanismus ab und setzen sie in einen (neg.) Rckgabe-  }
'{ wert um; fr Fehler, die nicht behandelt werden knnen, wird auerdem eine   }
'{ Meldung in die Datei                                                         }
'{                                                                              }
'{      I332_DLL.LOG                                                            }
'{                                                                              }
'{ geschrieben.                                                                 }
'{                                                                              }
'{ Die Funktionen I332IFCInit und I332DwnldFirmware erzeugen ebenfalls          }
'{ Log-Dateien; s. dort.                                                        }
'{                                                                              }
'{ Versions-/nderungsdokumentation: I332_DLL.PDF                               }
'{                                                                              }
'{ (c) 2000-2006 Dipl.Inform. Thomas Schneider                                  }
'{------------------------------------------------------------------------------}

Const DLLName = "I332.DLL"

'//------------------------------------------------------------------------------
'// Rckgabewerte der Routinen:
'// >= 0: kein Fehler bzw. Ergebnis
'// <  0: Interface-Fehler ieXXX    (s. I332_DEF.PAS)
'//------------------------------------------------------------------------------

'//------------------------------------------------------------------------------
'// I332IFCInit:
'//   > Initialisierung der I332-Schnittstelle
'//   > Aufbau der Kommunikation mit der I332
'//   ifcMode = imISA:
'//             ifcPara = 0
'//   ifcMode = imPCI
'//             ifcPara = lfd.Nr. der I332-PCI-Karte; 0 = 1. Karte etc.
'//   ifcMode = imUSB
'//             ifcPara = 0
'//   ifcMode = imCOM1..imCOM4
'//             ifcPara = Baudrate; ifcPara = 0 --> Baudrate = Default(57600Bd)
'//
'//   Ergebnis: Handle auf die I332-Schnittstelle bzw. (neg.) Fehlernr.
'//
'// War die Initialisierung erfolgreich, so wird auerdem die Datei
'//
'//    I332.LOG
'//
'// mit I332-Informationen geschrieben.
'//------------------------------------------------------------------------------

Declare Function I332IFCInit Lib "I332.DLL" (ByVal ifcMode As Integer, ByVal ifcPara As Long) As Long

'//------------------------------------------------------------------------------
'// I332IFCDone:
'//   > Beendet die Kommunikation mit der I332
'//   > Schliet ggf. die Schnittstelle bzw. beendet den Treiber
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332IFCDone Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
'Declare Function I332GetAxLabels Lib "I332.DLL" (Byval I332Handle as long, byref AAxLbls: TAxLbls) as long


'//------------------------------------------------------------------------------
'// I332GetIFCErrString
'//   liefert eine Klartextfehlermeldung fr die Fehlernr. AErrNo
'//   AErrNo:  Fehlernummer
'//   AErrStr: Buffer-Pointer, der den Fehlerstring aufnehmen soll;
'//            mu von der Anwendung zur Verfgung gestellt werden
'//   BufSize: Gre des Buffers
'//
'//   Ergebnis: tatschliche Lnge des Strings
'//             Ist AErrStr = NIL und/oder BufSize = 0, wird nur die bentigte
'//             Gre der Buffers zurckgeliefert
'//------------------------------------------------------------------------------
Declare Function I332GetIFCErrString Lib "I332.DLL" (ByVal AErrNo As Long, ByVal AErrStr As String, ByVal BufSize As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Reset Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Restart Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icRestart As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Write0 Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icSet As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Write1 Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icSet As Integer, Value As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Write2 Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icSet As Integer, Value As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Read1 Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icGet As Integer, ByRef Value As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Read2 Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icGet As Integer, ByRef Value As Long) As Long

'//------------------------------------------------------------------------------
'// I332DwnLdFirmware
'//   liest die neue Firmware aus der Datei AFileName und ldt sie auf die I332
'//   I332Handle: das von I332IFCInit gelieferte Handle
'//   AFileName:  Pointer auf den Dateinamen incl. Laufwerk/Pfad
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//
'// Informationen ber die aktuelle Firmware der I332 wird in die Datei
'//
'//              I332_alt_<Datum>_<Uhrzeit>.LOG
'//
'// geschrieben. Nach Beendigung der bertragung werden die neuen Firmware-Infos
'// in die Datei
'//
'//              I332_neu_<Datum>_<Uhrzeit>.LOG
'//
'// geschrieben. <Datum> und <Uhrzeit> sind dabei die aktuellen
'// System(nicht I332!)-Daten.
'//------------------------------------------------------------------------------
Declare Function I332DwnLdFirmware Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AFileName As String) As Long

'//------------------------------------------------------------------------------
'// I332FirmwareInfo
'//   liefert Informationen ber die Firmwaredatei AFileName
'//   AFileName:   Pointer auf einen Dateinamen
'//   AInfoStr:    Buffer-Pointer, der den Infostring aufnehmen soll;
'//                mu von der Anwendung zur Verfgung gestellt werden
'//   BufSize:     Gre des Buffers
'//   AI332InfoEx: weitere Informationen (s. Deklaration TI332InfoEx)
'//                vor dem Aufruf MUSS in jedem Fall die Gre der Struktur
'//                korrekt gesetzt werden:
'//                AI332InfoEx.Size := SizeOf(AI332InfoEx)
'//
'//   Ergebnis: tatschliche Lnge des Strings oder (neg.) Fehlernummer
'//             Ist AInfoStr = NIL und/oder BufSize = 0, wird nur die bentigte
'//             Gre des Buffers zurckgeliefert; auch in diesem Fall wird
'//             AI332InfoEx korrekt zurckgeliefert!
'//------------------------------------------------------------------------------
Declare Function I332FirmwareInfo Lib "I332.DLL" (ByVal AFileName As String, ByVal AInfoStr As String, ByVal BufSize As Long, ByRef AI332InfoEx As TI332InfoEx) As Long

'//------------------------------------------------------------------------------
'// I332DLLVersion
'//   Ergebnis: DLL-Version als Langwort $vvrrbbbb
'//             zu interpretieren als vv.rr.bbbb
'//------------------------------------------------------------------------------
Declare Function I332DLLVersion Lib "I332.DLL" () As Long

'//------------------------------------------------------------------------------
'//
'//------------------------------------------------------------------------------
Declare Function I332GetIFCErr Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetInfo Lib "I332.DLL" (ByVal I332Handle As Long, ByRef I332Info As TI332Info) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetInfoEx Lib "I332.DLL" (ByVal I332Handle As Long, ByRef AI332InfoEx As TI332InfoEx) As Long

'//------------------------------------------------------------------------------
'// I332GetVerStr
'//   liefert den Versionsstring der I332
'//  I332Handle: das von I332IFCInit gelieferte Handle
'//   VerStr:     Buffer-Pointer, der den Versionsstring aufnehmen soll;
'//               mu von der Anwendung zur Verfgung gestellt werden
'//   BufSize:    Gre des Buffers
'//
'//   Ergebnis: tatschliche Lnge des Strings oder (neg.) Fehlernummer
'//             Ist VerStr = NIL und/oder BufSize = 0, wird nur die bentigte
'//             Gre der Buffers zurckgeliefert
'//------------------------------------------------------------------------------
Declare Function I332GetVerStr Lib "I332.DLL" (ByVal I332Handle As Long, ByVal VerStr As String, ByVal BufSize As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332MutexName Lib "I332.DLL" (ByVal I332Handle As Long, ByVal Buffer As String, ByVal BufSize As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332WaitForMutex Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332ReleaseMutex Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332SetAchsReg Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icSet As Integer, ByVal AxisNo As Byte, ByVal Value As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetAchsReg Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icGet As Integer, ByVal AxisNo As Byte, ByRef Value As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332AchsReg Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icGet As Integer, ByVal AxisNo As Byte) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetStatus Lib "I332.DLL" (ByVal I332Handle As Long, ByRef I332Status As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetRefInfo Lib "I332.DLL" (ByVal I332Handle As Long, ByRef RefInfo As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332ZyklusStart Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332ZyklusStop Lib "I332.DLL" (ByVal I332Handle As Long) As Long


'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoZyklusStart Lib "I332.DLL" (ByVal I332Handle As Long, ByVal start As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetPos Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisNo As Byte, ByRef IstWert As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332Pos Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisNo As Byte) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetVIst Lib "I332.DLL" (ByVal I332Handle As Long, ByRef Value As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332VIst Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoPos1 Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisNr As Byte, ByVal Dist As Long, ByVal F As Long, ByVal Flags As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoIPLLin Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisCnt As Byte, ByRef AxArray As TAxisArray, ByVal F As Long, ByVal Flags As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoIPLCW Lib "I332.DLL" (ByVal I332Handle As Long, _
                     ByVal AxisCnt As Byte, ByRef AxArray As TAxisArray, ByVal F As Long, ByVal Flags As Long, _
                     ByVal XAx As Byte, ByVal YAx As Byte, ByVal XMP As Long, ByVal YMP As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoIPLCCW Lib "I332.DLL" (ByVal I332Handle As Long, _
                     ByVal AxisCnt As Byte, ByRef AxArray As TAxisArray, ByVal F As Long, ByVal Flags As Long, _
                     ByVal XAx As Byte, ByVal YAx As Byte, ByVal XMP As Long, ByVal YMP As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoDelay Lib "I332.DLL" (ByVal I332Handle As Long, ByVal F As Long, ByVal Flags As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoAxisRef Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisNo As Byte) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoAxisAsync Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisNo As Byte, ByVal Dist As Long, ByVal HndF As Long, ByVal sfMode As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332DoAxisHand Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AxisNo As Byte, ByVal HndF As Long, ByVal fMode As Integer) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332XmtCFG Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AINIFileName As String) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332ExecCfgDlg Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AINIFileName As String) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332ExecTstDlg Lib "I332.DLL" (ByVal I332Handle As Long, ByVal AMode As Long) As Long

'{**********************************************************************}

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332GetAxArray Lib "I332.DLL" (ByVal I332Handle As Long, ByVal icGet As Integer, ByRef AxArray As TAxisArray) As Long

'{------------------------------------------------------------------------------}
'{ gepufferte Kommunikation, insb. fr USB                                      }
'{------------------------------------------------------------------------------}

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
'Declare Function I332XmtBuffer Lib "I332.DLL" (Byval I332Handle as long, by???Buffer: Pointer; WordCnt: Cardinal) as long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: I332BufHandle bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
'Declare Function I332InitBuffer Lib "I332.DLL" (Byval I332Handle as long; Buffer: Pointer; MaxSize as long AW_O: BOOL) as long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332FreeBuffer Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332FlushBuffer Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
Declare Function I332ClearBuffer Lib "I332.DLL" (ByVal I332Handle As Long) As Long

'//------------------------------------------------------------------------------
'//
'//   Ergebnis: 0 bzw. (neg.) Fehlernr.
'//------------------------------------------------------------------------------
'Declare Function I332GetBuffer Lib "I332.DLL" (Byval I332Handle as long; Buffer: Pointer; WordCnt,WordPos as long) as long


