unit I332_IFC;

{------------------------------------------------------------------------------}
{ Interface-Unit fr die I332.DLL:                                             }
{ Schnittstellen-DLL fr die Maschinensteuerung I332 / Fa. Pfortner Ltd.       }
{                                                                              }
{ Alle Schnittstelle-Routinen sind Funktionen, die ein (positives)             }
{ Funktionsergebnis oder eine (negative) Fehlernummer zurckliefern.           }
{ Die DLL ist in der Lage, mehrere I332 in einem System  zu verwalten.         }
{ Die Kommunikation mit einer spezifischen I332 erfolgt ber ein Handle, das   }
{ durch den Aufruf der Initialisierungsfunktion bereitgestellt wird.           }
{                                                                              }
{ Alle Routinen benutzen das Aufruf-Modell stdcall (entspr. der                }
{ C/C++ - Direktive "WinAPI").                                                 }
{                                                                              }
{ Die I332.DLL ist threadfest; alle Funktionen fangen mgliche Fehler          }
{ mit dem try..except-Mechanismus ab und setzen sie in einen (neg.) Rckgabe-  }
{ wert um; fr Fehler, die nicht behandelt werden knnen, wird auerdem eine   }
{ Meldung in die Datei                                                         }
{                                                                              }
{       I332_DLL.LOG                                                           }
{                                                                              }
{ geschrieben.                                                                 }
{                                                                              }
{ Die Funktionen I332IFCInit und I332DwnldFirmware erzeugen ebenfalls          }
{ Log-Dateien; s. dort.                                                        }
{                                                                              }
{ Versions-/nderungsdokumentation: I332_DLL.PDF                               }
{                                                                              }
{ (c) 2000-2008 Dipl.Inform. Thomas Schneider                                  }
{------------------------------------------------------------------------------}

interface

uses Windows, i332_def;

CONST DLLName = 'I332.DLL';

//------------------------------------------------------------------------------
// Rckgabewerte der Routinen:
// >= 0: kein Fehler bzw. Ergebnis
// <  0: Interface-Fehler ieXXX    (s. I332_DEF.PAS)
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
// I332IFCInit:
//   > Initialisierung der I332-Schnittstelle
//   > Aufbau der Kommunikation mit der I332
//   ifcMode = imISA:
//             ifcPara = 0
//   ifcMode = imPCI
//             ifcPara = lfd.Nr. der I332-PCI-Karte; 0 = 1. Karte etc.
//   ifcMode = imUSB
//             ifcPara = 0
//   ifcMode = imCOM1..imCOM4
//             ifcPara = Baudrate; ifcPara = 0 --> Baudrate = Default(57600Bd)
//
//   Ergebnis: Handle auf die I332-Schnittstelle bzw. (neg.) Fehlernr.
//
// War die Initialisierung erfolgreich, so wird auerdem die Datei
//
//     I332.LOG
//
// mit I332-Informationen geschrieben.
//------------------------------------------------------------------------------
FUNCTION I332IFCInit(ifcMode: WORD; ifcPara: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
// I332IFCDone:
//   > Beendet die Kommunikation mit der I332
//   > Schliet ggf. die Schnittstelle bzw. beendet den Treiber
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332IFCDone(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetAxLabels(I332Handle: INTEGER; VAR AAxLbls: TAxLbls): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
// I332GetIFCErrString
//   liefert eine Klartextfehlermeldung fr die Fehlernr. AErrNo
//   AErrNo:  Fehlernummer
//   AErrStr: Buffer-Pointer, der den Fehlerstring aufnehmen soll;
//            mu von der Anwendung zur Verfgung gestellt werden
//   BufSize: Gre des Buffers
//
//   Ergebnis: tatschliche Lnge des Strings
//             Ist AErrStr = NIL und/oder BufSize = 0, wird nur die bentigte
//             Gre der Buffers zurckgeliefert
//------------------------------------------------------------------------------
FUNCTION I332GetIFCErrString(AErrNo: LONGINT; AErrStr: PChar; BufSize: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Reset(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Restart(I332Handle: INTEGER; icRestart: WORD): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332InitMP(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Write0(I332Handle: INTEGER; icSet: WORD): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Write1(I332Handle: INTEGER; icSet: WORD; Value: WORD): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Write2(I332Handle: INTEGER; icSet: WORD; Value: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Read1(I332Handle: INTEGER; icGet: WORD; VAR Value: WORD): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Read2(I332Handle: INTEGER; icGet: WORD; VAR Value: LONGINT): INTEGER;
stdcall; external DLLName;


//------------------------------------------------------------------------------
// I332DwnLdFirmware
//   liest die neue Firmware aus der Datei AFileName und ldt sie auf die I332
//   I332Handle: das von I332IFCInit gelieferte Handle
//   AFileName:  Pointer auf den Dateinamen incl. Laufwerk/Pfad
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//
// Informationen ber die aktuelle Firmware der I332 wird in die Datei
//
//               I332_alt_<Datum>_<Uhrzeit>.LOG
//
// geschrieben. Nach Beendigung der bertragung werden die neuen Firmware-Infos
// in die Datei
//
//               I332_neu_<Datum>_<Uhrzeit>.LOG
//
// geschrieben. <Datum> und <Uhrzeit> sind dabei die aktuellen
// System(nicht I332!)-Daten.
//------------------------------------------------------------------------------
FUNCTION I332DwnLdFirmware(I332Handle: INTEGER; AFileName: PChar): LONGINT;
stdcall; external DLLName;

//------------------------------------------------------------------------------
// I332FirmwareInfo
//   liefert Informationen ber die Firmwaredatei AFileName
//   AFileName:   Pointer auf einen Dateinamen
//   AInfoStr:    Buffer-Pointer, der den Infostring aufnehmen soll;
//                mu von der Anwendung zur Verfgung gestellt werden
//   BufSize:     Gre des Buffers
//   AI332InfoEx: weitere Informationen (s. Deklaration TI332InfoEx)
//                vor dem Aufruf MUSS in jedem Fall die Gre der Struktur
//                korrekt gesetzt werden:
//                AI332InfoEx.Size := SizeOf(AI332InfoEx)
//
//   Ergebnis: tatschliche Lnge des Strings oder (neg.) Fehlernummer
//             Ist AInfoStr = NIL und/oder BufSize = 0, wird nur die bentigte
//             Gre der Buffers zurckgeliefert; auch in diesem Fall wird
//             AI332InfoEx korrekt zurckgeliefert!
//------------------------------------------------------------------------------
FUNCTION I332FirmwareInfo(AFileName: PChar; AInfoStr: PChar; BufSize: INTEGER; VAR AI332InfoEx: TI332InfoEx): LONGINT;
stdcall; external DLLName;


//------------------------------------------------------------------------------
// I332DLLVersion
//   Ergebnis: DLL-Version als Langwort $vvrrbbbb
//             zu interpretieren als vv.rr.bbbb
//------------------------------------------------------------------------------
FUNCTION I332DLLVersion: LONGINT;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//------------------------------------------------------------------------------
FUNCTION I332GetIFCErr(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetInfo(I332Handle: INTEGER; VAR I332Info: TI332Info): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetInfoEx(I332Handle: INTEGER; VAR AI332InfoEx: TI332InfoEx): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
// I332GetVerStr
//   liefert den Versionsstring der I332
//   I332Handle: das von I332IFCInit gelieferte Handle
//   VerStr:     Buffer-Pointer, der den Versionsstring aufnehmen soll;
//               mu von der Anwendung zur Verfgung gestellt werden
//   BufSize:    Gre des Buffers
//
//   Ergebnis: tatschliche Lnge des Strings oder (neg.) Fehlernummer
//             Ist VerStr = NIL und/oder BufSize = 0, wird nur die bentigte
//             Gre der Buffers zurckgeliefert
//------------------------------------------------------------------------------
FUNCTION I332GetVerStr(I332Handle: INTEGER; VerStr: PChar; BufSize: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332MutexName(I332Handle: INTEGER; Buffer: PChar; BufSize: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332WaitForMutex(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332ReleaseMutex(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;


//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332SetAchsReg(I332Handle: INTEGER; icSet: WORD; AxisNo: ShortInt; Value: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetAchsReg(I332Handle: INTEGER; icGet: WORD; AxisNo: ShortInt; VAR Value: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332AchsReg(I332Handle: INTEGER; icGet: WORD; AxisNo: ShortInt): LONGINT;
stdcall; external DLLName;


//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetStatus(I332Handle: INTEGER; VAR I332Status: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetRefInfo(I332Handle: INTEGER; VAR RefInfo: WORD): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetSFStatus(I332Handle: INTEGER; VAR SFStatus: WORD): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332ZyklusStart(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332ZyklusStop(I332Handle: INTEGER): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoZyklusStart(I332Handle: INTEGER; Start: BOOL): INTEGER;
stdcall; external DLLName;


//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetPos(I332Handle: INTEGER; AxisNo: ShortInt; VAR IstWert: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332Pos(I332Handle: INTEGER; AxisNo: ShortInt): LONGINT;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetVIst(I332Handle: INTEGER; VAR Value: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332VIst(I332Handle: INTEGER): LONGINT;
stdcall; external DLLName;


//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoPos1(I332Handle: INTEGER; AxisNr: ShortInt; Dist,F: LONGINT; Flags: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoIPLLin(I332Handle: INTEGER; AxisCnt: ShortInt; CONST AxArray: TAxisArray; F: LONGINT; Flags: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoIPLCW(I332Handle: INTEGER;
                     AxisCnt: ShortInt; CONST AxArray: TAxisArray; F: LONGINT; Flags: LONGINT;
                     XAx,YAx: ShortInt; XMP,YMP: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoIPLCCW(I332Handle: INTEGER;
                      AxisCnt: ShortInt; CONST AxArray: TAxisArray; F: LONGINT; Flags: LONGINT;
                      XAx,YAx: ShortInt; XMP,YMP: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoDelay(I332Handle: INTEGER; F: LONGINT; Flags: LONGINT): INTEGER;
stdcall; external DLLName;


//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoAxisRef(I332Handle: INTEGER; AxisNo: ShortInt): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoAxisAsync(I332Handle: INTEGER; AxisNo: ShortInt; Dist,HndF: LONGINT; sfMode: WORD): LONGINT;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332DoAxisHand(I332Handle: INTEGER; AxisNo: ShortInt; HndF: LONGINT; sfMode: WORD): INTEGER;
stdcall; external DLLName;


//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332XmtCFG(I332Handle: INTEGER; AINIFileName: PChar): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332ExecCfgDlg(AI332Handle: INTEGER; AINIFileName: PChar): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332ExecTstDlg(AI332Handle: INTEGER; AMode: INTEGER): INTEGER;
stdcall; external DLLName;

{**********************************************************************}

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetAxArray(I332Handle: INTEGER; icGet: WORD; VAR AxArray: TAxisArray): INTEGER;
stdcall; external DLLName;

{------------------------------------------------------------------------------}
{ gepufferte Kommunikation, insb. fr USB                                      }
{------------------------------------------------------------------------------}

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332XmtBuffer(I332Handle: INTEGER; Buffer: Pointer; WordCnt: Cardinal): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: I332BufHandle bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332InitBuffer(I332Handle: INTEGER; Buffer: Pointer; MaxSize: INTEGER; AW_O: BOOL): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332FreeBuffer(I332Handle: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332FlushBuffer(I332Handle: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332ClearBuffer(I332Handle: LONGINT): INTEGER;
stdcall; external DLLName;

//------------------------------------------------------------------------------
//
//   Ergebnis: 0 bzw. (neg.) Fehlernr.
//------------------------------------------------------------------------------
FUNCTION I332GetBuffer(I332Handle: LONGINT; Buffer: Pointer; WordCnt,WordPos: INTEGER): INTEGER;
stdcall; external DLLName;

implementation

initialization
finalization
end.

